pub fn compiled_result_columns(compiled: &CompiledQuery) -> Vec<String>Expand description
Result column names for a compiled query (head plan; UNION branches must produce the same shape so the head’s columns are authoritative).
pub fn compiled_result_columns(compiled: &CompiledQuery) -> Vec<String>Result column names for a compiled query (head plan; UNION branches must produce the same shape so the head’s columns are authoritative).